@@ -66,7 +66,7 @@ private:
   Lum::Model::BooleanRef paused;
   Lum::Model::ActionRef  stopAction;
   Lum::Model::ActionRef  timer;
-  Lum::Model::SizeTRef   seconds;
+  Lum::Model::ULongRef   seconds;
 
   size_t                 initialSeconds;
   Lum::Base::Timer       time;
@@ -83,7 +83,7 @@ public:
     paused(new Lum::Model::Boolean(false)),
     stopAction(new Lum::Model::Action()),
     timer(new Lum::Model::Action()),
-    seconds(new Lum::Model::SizeT()),
+    seconds(new Lum::Model::ULong()),
     initialSeconds(0),
     state(stateUninitialized),
     value(new StopWatch()),
