@@ -30,13 +30,13 @@ class TeeEdit : public Lum::Dlg::ActionDialog
 {
 private:
   Lum::Model::StringRef name;
-  Lum::Model::SizeTRef  seconds;
+  Lum::Model::NumberRef seconds;
   Lum::Model::ActionRef okAction;
   bool                  success;
 
 public:
   TeeEdit(Lum::Model::String* name,
-          Lum::Model::SizeT *seconds);
+          Lum::Model::Number* seconds);
   ~TeeEdit();
 
   Lum::Object* GetContent();
